@@ -4,6 +4,21 @@
  * SPDX-License-Identifier: Apache-2.0 OR MIT
  */
 
+use super::{parse::TxtRecordParser, verify::DomainKey};
+use crate::{
+    Error, IpLookupStrategy, MX, MessageAuthenticator, ResolverCache, Txt,
+    dkim::{Atps, DomainKeyReport},
+    dmarc::Dmarc,
+    mta_sts::{MtaSts, TlsRpt},
+    spf::{Macro, Spf},
+};
+use hickory_resolver::{
+    Name, TokioResolver,
+    config::{ResolverConfig, ResolverOpts},
+    name_server::TokioConnectionProvider,
+    proto::{ProtoError, ProtoErrorKind},
+    system_conf::read_system_conf,
+};
 use std::{
     borrow::Cow,
     net::{IpAddr, Ipv4Addr, Ipv6Addr},
@@ -11,59 +26,46 @@ use std::{
     time::Instant,
 };
 
-use hickory_resolver::{
-    config::{ResolverConfig, ResolverOpts},
-    error::{ResolveError, ResolveErrorKind},
-    system_conf::read_system_conf,
-    AsyncResolver, Name, TokioAsyncResolver,
-};
-
-use crate::{
-    dkim::{Atps, DomainKeyReport},
-    dmarc::Dmarc,
-    mta_sts::{MtaSts, TlsRpt},
-    spf::{Macro, Spf},
-    Error, IpLookupStrategy, MessageAuthenticator, ResolverCache, Txt, MX,
-};
-
-use super::{parse::TxtRecordParser, verify::DomainKey};
-
 pub struct DnsEntry<T> {
     pub entry: T,
     pub expires: Instant,
 }
 
 impl MessageAuthenticator {
-    pub fn new_cloudflare_tls() -> Result<Self, ResolveError> {
+    pub fn new_cloudflare_tls() -> Result<Self, ProtoError> {
         Self::new(ResolverConfig::cloudflare_tls(), ResolverOpts::default())
     }
 
-    pub fn new_cloudflare() -> Result<Self, ResolveError> {
+    pub fn new_cloudflare() -> Result<Self, ProtoError> {
         Self::new(ResolverConfig::cloudflare(), ResolverOpts::default())
     }
 
-    pub fn new_google() -> Result<Self, ResolveError> {
+    pub fn new_google() -> Result<Self, ProtoError> {
         Self::new(ResolverConfig::google(), ResolverOpts::default())
     }
 
-    pub fn new_quad9() -> Result<Self, ResolveError> {
+    pub fn new_quad9() -> Result<Self, ProtoError> {
         Self::new(ResolverConfig::quad9(), ResolverOpts::default())
     }
 
-    pub fn new_quad9_tls() -> Result<Self, ResolveError> {
+    pub fn new_quad9_tls() -> Result<Self, ProtoError> {
         Self::new(ResolverConfig::quad9_tls(), ResolverOpts::default())
     }
 
-    pub fn new_system_conf() -> Result<Self, ResolveError> {
+    pub fn new_system_conf() -> Result<Self, ProtoError> {
         let (config, options) = read_system_conf()?;
         Self::new(config, options)
     }
 
-    pub fn new(config: ResolverConfig, options: ResolverOpts) -> Result<Self, ResolveError> {
-        Ok(MessageAuthenticator(AsyncResolver::tokio(config, options)))
+    pub fn new(config: ResolverConfig, options: ResolverOpts) -> Result<Self, ProtoError> {
+        Ok(MessageAuthenticator(
+            TokioResolver::builder_with_config(config, TokioConnectionProvider::default())
+                .with_options(options)
+                .build(),
+        ))
     }
 
-    pub fn resolver(&self) -> &TokioAsyncResolver {
+    pub fn resolver(&self) -> &TokioResolver {
         &self.0
     }
 
@@ -76,7 +78,7 @@ impl MessageAuthenticator {
             .as_lookup()
             .record_iter()
         {
-            if let Some(txt_data) = record.data().and_then(|r| r.as_txt()) {
+            if let Some(txt_data) = record.data().as_txt() {
                 for item in txt_data.txt_data() {
                     result.extend_from_slice(item);
                 }
@@ -107,7 +109,7 @@ impl MessageAuthenticator {
             .await?;
         let mut result = Err(Error::InvalidRecordType);
         let records = txt_lookup.as_lookup().record_iter().filter_map(|r| {
-            let txt_data = r.data()?.as_txt()?.txt_data();
+            let txt_data = r.data().as_txt()?.txt_data();
             match txt_data.len() {
                 1 => Some(Cow::from(txt_data[0].as_ref())),
                 0 => None,
@@ -159,7 +161,7 @@ impl MessageAuthenticator {
         let mx_records = mx_lookup.as_lookup().records();
         let mut records: Vec<MX> = Vec::with_capacity(mx_records.len());
         for mx_record in mx_records {
-            if let Some(mx) = mx_record.data().and_then(|r| r.as_mx()) {
+            if let Some(mx) = mx_record.data().as_mx() {
                 let preference = mx.preference();
                 let exchange = mx.exchange().to_lowercase().to_string();
 
@@ -217,7 +219,7 @@ impl MessageAuthenticator {
         let ips: Arc<Vec<Ipv4Addr>> = ipv4_lookup
             .as_lookup()
             .record_iter()
-            .filter_map(|r| r.data()?.as_a()?.0.into())
+            .filter_map(|r| r.data().as_a()?.0.into())
             .collect::<Vec<Ipv4Addr>>()
             .into();
 
@@ -260,7 +262,7 @@ impl MessageAuthenticator {
         let ips: Arc<Vec<Ipv6Addr>> = ipv6_lookup
             .as_lookup()
             .record_iter()
-            .filter_map(|r| r.data()?.as_aaaa()?.0.into())
+            .filter_map(|r| r.data().as_aaaa()?.0.into())
             .collect::<Vec<Ipv6Addr>>()
             .into();
 
@@ -288,7 +290,7 @@ impl MessageAuthenticator {
                                 .take(max_results)
                                 .copied()
                                 .map(IpAddr::from)
-                                .collect())
+                                .collect());
                         }
                         (Err(err), IpLookupStrategy::Ipv4Only) => return Err(err),
                         _ => {
@@ -304,7 +306,7 @@ impl MessageAuthenticator {
                                 .take(max_results)
                                 .copied()
                                 .map(IpAddr::from)
-                                .collect())
+                                .collect());
                         }
                         (Err(err), IpLookupStrategy::Ipv6Only) => return Err(err),
                         _ => {
@@ -335,7 +337,7 @@ impl MessageAuthenticator {
             .as_lookup()
             .record_iter()
             .filter_map(|r| {
-                let r = r.data()?.as_ptr()?;
+                let r = r.data().as_ptr()?;
                 if !r.is_empty() {
                     r.to_lowercase().to_string().into()
                 } else {
@@ -394,30 +396,25 @@ impl MessageAuthenticator {
             .await
         {
             Ok(result) => Ok(result.as_lookup().record_iter().any(|r| {
-                r.data().is_some_and(|d| {
-                    matches!(
-                        d.record_type(),
-                        hickory_resolver::proto::rr::RecordType::A
-                            | hickory_resolver::proto::rr::RecordType::AAAA
-                    )
-                })
+                matches!(
+                    r.data().record_type(),
+                    hickory_resolver::proto::rr::RecordType::A
+                        | hickory_resolver::proto::rr::RecordType::AAAA
+                )
             })),
-            Err(err) => {
-                if matches!(err.kind(), ResolveErrorKind::NoRecordsFound { .. }) {
-                    Ok(false)
-                } else {
-                    Err(err.into())
-                }
-            }
+            Err(err) => match err.kind() {
+                ProtoErrorKind::NoRecordsFound { .. } => Ok(false),
+                _ => Err(err.into()),
+            },
         }
     }
 }
 
-impl From<ResolveError> for Error {
-    fn from(err: ResolveError) -> Self {
+impl From<ProtoError> for Error {
+    fn from(err: ProtoError) -> Self {
         match err.kind() {
-            ResolveErrorKind::NoRecordsFound { response_code, .. } => {
-                Error::DnsRecordNotFound(*response_code)
+            ProtoErrorKind::NoRecordsFound(response_code) => {
+                Error::DnsRecordNotFound(response_code.response_code)
             }
             _ => Error::DnsError(err.to_string()),
         }
