@@ -4,19 +4,16 @@
  * SPDX-License-Identifier: Apache-2.0 OR MIT
  */
 
-use std::time::SystemTime;
-
-use mail_builder::encoders::base64::base64_encode;
-
-use super::{canonicalize::CanonicalHeaders, DkimSigner, Done, Signature};
-
+use super::{DkimSigner, Done, Signature, canonicalize::CanonicalHeaders};
 use crate::{
+    Error,
     common::{
         crypto::SigningKey,
         headers::{ChainedHeaderIterator, HeaderIterator, HeaderStream, Writable, Writer},
     },
-    Error,
 };
+use mail_builder::encoders::base64::base64_encode;
+use std::time::SystemTime;
 
 impl<T: SigningKey> DkimSigner<T, Done> {
     /// Signs a message.
@@ -88,8 +85,8 @@ impl<T: SigningKey> DkimSigner<T, Done> {
 }
 
 pub(super) struct SignableMessage<'a> {
-    headers: CanonicalHeaders<'a>,
-    signature: &'a Signature,
+    pub(super) headers: CanonicalHeaders<'a>,
+    pub(super) signature: &'a Signature,
 }
 
 impl Writable for SignableMessage<'_> {
@@ -102,13 +99,8 @@ impl Writable for SignableMessage<'_> {
 #[cfg(test)]
 #[allow(unused)]
 pub mod test {
-    use core::str;
-    use std::time::{Duration, Instant};
-
-    use hickory_resolver::proto::op::ResponseCode;
-    use mail_parser::{decoders::base64::base64_decode, MessageParser};
-
     use crate::{
+        AuthenticatedMessage, DkimOutput, DkimResult, MessageAuthenticator,
         common::{
             cache::test::DummyCaches,
             crypto::{Ed25519Key, RsaKey, Sha256},
@@ -117,8 +109,12 @@ pub mod test {
             verify::DomainKey,
         },
         dkim::{Atps, Canonicalization, DkimSigner, DomainKeyReport, HashAlgorithm, Signature},
-        AuthenticatedMessage, DkimOutput, DkimResult, MessageAuthenticator,
     };
+    use core::str;
+    use hickory_resolver::proto::op::ResponseCode;
+    use mail_parser::{MessageParser, decoders::base64::base64_decode};
+    use rustls_pki_types::{PrivateKeyDer, PrivatePkcs1KeyDer, pem::PemObject};
+    use std::time::{Duration, Instant};
 
     const RSA_PRIVATE_KEY: &str = include_str!("../../resources/rsa-private.pem");
 
@@ -138,14 +134,14 @@ pub mod test {
     const ED25519_PUBLIC_KEY: &str =
         "v=DKIM1; k=ed25519; p=11qYAYKxCrfVS/7TyWQHOg7hcvPapiMlrwIaaPcHURo=";
 
-    #[cfg(any(
-        feature = "rust-crypto",
-        all(feature = "ring", feature = "rustls-pemfile")
-    ))]
+    #[cfg(any(feature = "rust-crypto", feature = "ring"))]
     #[test]
     fn dkim_sign() {
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         #[cfg(feature = "rust-crypto")]
         let pk = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         let signature = DkimSigner::from_key(pk)
@@ -183,10 +179,7 @@ pub mod test {
         );
     }
 
-    #[cfg(any(
-        feature = "rust-crypto",
-        all(feature = "ring", feature = "rustls-pemfile")
-    ))]
+    #[cfg(any(feature = "rust-crypto", feature = "ring"))]
     #[tokio::test]
     async fn dkim_sign_verify() {
         use crate::common::cache::test::DummyCaches;
@@ -254,7 +247,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         verify(
             &resolver,
             &caches,
@@ -289,7 +285,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         verify(
             &resolver,
             &caches,
@@ -309,7 +308,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         verify(
             &resolver,
             &caches,
@@ -331,7 +333,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         verify(
             &resolver,
             &caches,
@@ -358,7 +363,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         verify_with_opts(
             &resolver,
             &caches,
@@ -380,7 +388,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         verify_with_opts(
             &resolver,
             &caches,
@@ -402,7 +413,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         verify(
             &resolver,
             &caches,
@@ -422,7 +436,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         let r = verify(
             &resolver,
             &caches,
@@ -447,7 +464,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         verify(
             &resolver,
             &caches,
@@ -468,7 +488,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         caches.txt_add(
             "UN42N5XOV642KXRXRQIYANHCOUPGQL5LT4WTBKYT2IJFLBWODFDQ._atps.example.com.".to_string(),
             Atps::parse(b"v=ATPS1;").unwrap(),
@@ -494,7 +517,10 @@ pub mod test {
         #[cfg(feature = "rust-crypto")]
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
-        let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
+        let pk_rsa = RsaKey::<Sha256>::from_key_der(PrivateKeyDer::Pkcs1(
+            PrivatePkcs1KeyDer::from_pem_slice(RSA_PRIVATE_KEY.as_bytes()).unwrap(),
+        ))
+        .unwrap();
         caches.txt_add(
             "example.com._atps.example.com.".to_string(),
             Atps::parse(b"v=ATPS1;").unwrap(),
