@@ -4,21 +4,19 @@
  * SPDX-License-Identifier: Apache-2.0 OR MIT
  */
 
+use super::{
+    Directive, Macro, Mechanism, Qualifier, RR_FAIL, RR_NEUTRAL_NONE, RR_SOFTFAIL,
+    RR_TEMP_PERM_ERROR, Spf, Variable,
+};
+use crate::{
+    Error, Version,
+    common::parse::{TagParser, TxtRecordParser, V},
+};
 use std::{
     net::{Ipv4Addr, Ipv6Addr},
     slice::Iter,
 };
 
-use crate::{
-    common::parse::{TagParser, TxtRecordParser, V},
-    Error, Version,
-};
-
-use super::{
-    Directive, Macro, Mechanism, Qualifier, Spf, Variable, RR_FAIL, RR_NEUTRAL_NONE, RR_SOFTFAIL,
-    RR_TEMP_PERM_ERROR,
-};
-
 impl TxtRecordParser for Spf {
     fn parse(bytes: &[u8]) -> crate::Result<Spf> {
         let mut record = bytes.iter();
@@ -734,8 +732,8 @@ mod test {
     use crate::{
         common::parse::TxtRecordParser,
         spf::{
-            Directive, Macro, Mechanism, Qualifier, Spf, Variable, Version, RR_FAIL,
-            RR_NEUTRAL_NONE, RR_SOFTFAIL, RR_TEMP_PERM_ERROR,
+            Directive, Macro, Mechanism, Qualifier, RR_FAIL, RR_NEUTRAL_NONE, RR_SOFTFAIL,
+            RR_TEMP_PERM_ERROR, Spf, Variable, Version,
         },
     };
 
@@ -1423,7 +1421,7 @@ mod test {
                 },
             ),
             (
-                concat!("v=spf1 mx:example.org -all ra=postmaster rp=15 rr=e:f:s:n"),
+                "v=spf1 mx:example.org -all ra=postmaster rp=15 rr=e:f:s:n",
                 Spf {
                     version: Version::V1,
                     ra: b"postmaster".to_vec().into(),
@@ -1445,7 +1443,7 @@ mod test {
                 },
             ),
             (
-                concat!("v=spf1 ip6:fe80:0000:0000::0000:0000:0000:1 -all"),
+                "v=spf1 ip6:fe80:0000:0000::0000:0000:0000:1 -all",
                 Spf {
                     version: Version::V1,
                     ra: None,
